@@ -1,4 +1,4 @@
-package Finance::CoinbasePro::API::CLI; # Command-line interface to GDAX / Coinbase Pro
+package Finance::CoinbasePro::API::CLI;
 
 use 5.006;
 use strict;
@@ -10,8 +10,7 @@ Finance::CoinbasePro::API::CLI - Command-line interface to GDAX / Coinbase Pro
 
 =cut
 
-our $VERSION = '0.000_14'; # TRIAL
-$VERSION =~ tr/_//d;
+our $VERSION = '0.000_06';
 
 
 =head1 SYNOPSIS
@@ -98,11 +97,12 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
 
-Finance::CoinbasePro::API::CLI - Command-line interface to GDAX / Coinbase Pro
+Finance::CoinbasePro::API::CLI
 
 
 =head1 DESCRIPTION
